## Building the Python Documentation

This directory contains Sphinx configuration files for building the
libsbp Python documentation.

```shell
# Install Sphinx requirements
sudo pip install -r requirements.txt

# Build HTML documentation autogenerated from source
make html
```
